

/*
    This is a sketch to configure a Bluetooth Module.
    Soft Serial Speed will need setting to whatever the Bluetooth Moduel is set to.

    There are two modes a Bluetooth Module can be in.
    Depending on the mode and the type of Blue tooth Module, the speeds can be different.

    I have added a LCD to remind me what the Serial is set to.
*/

#include <Wire.h>
#include <LiquidCrystal_I2C.h>
#include <SoftwareSerial.h>

/*
    Hard Serial communications to/from USB

    9600, 38400*, 57600, 115200 Set this to what you prefire.
    The Serial Monitor needs to be set to the same.

*/
#define HARD_SPEED  115200
/*
    Soft Serial communications to/from Module

    Defaults:
    HC-05 (6 pin) = Data Mode = 9600 Command Mode = 38400 (Set at Boot).
    HC-06 (4 pin) = Data Mode = 9600 Command Mode = 9600 (both are the same when changed).

*/
#define SOFT_SPEED  9600

#define TX A2                     /*  Arduino TX to Module RX.  */
#define RX A3                     /*  Arduino TX to Module RX.  */
SoftwareSerial S_Serial(RX, TX);  /*  (Arduino RX, Arduino TX ) */

/*
  Liquid Crystal Display
  Via I2C
*/
LiquidCrystal_I2C lcd(0x27, 16, 2);

void setup() {

  /*    Open serial communications for the USB  */
  Serial.begin(HARD_SPEED);
  Serial.println("Ready to Recive...");

  /*    Open serial communications for the Module.    */
  S_Serial.begin(SOFT_SPEED);

  lcd.init();
  lcd.backlight();
  lcd.print("S Serial ");
  lcd.print(SOFT_SPEED);
  lcd.setCursor(0, 1);/*  bottom line */
  lcd.print("H Serial ");
  lcd.print(HARD_SPEED);

}

char a = 0;
char b = 0;
void loop() {

  S_Serial.listen();
  if (S_Serial.available()) {
    a = S_Serial.read();
    Serial.print(a);
  }

  if (Serial.available()) {
    b = Serial.read();
    S_Serial.print(b);
  }
  delay(10);
}
